для запуска бота надо:
дать переменные среды
VK_API_TOKEN - по нему бот получит доступ к сообщениям группы
DB_FILE_NAME - название базы данных

перед началом работы создайте базу данных, запустите в ней срипт init.sql

чтобы вернуть базу к изначальному состоянию, запустите db_to_start.sql
ВАЖНО: не запускайте его в базе, где уже есть ценные данные, он их необратимо сотрёт

чтобы запустить робота, запустите bot/main.py

по любым вопросам пишите на https://vk.com/o.demyanchenko
